"""
Colored consoles(Ansi formatting),
Written in c++ by 'Arman Ahmadi' with (armanagha6@gmail.com) email!

Ansi mode will enable automatically

Supported OS's:
- windows(MS-DOS Console)
- unix base(bash)
"""
from .colored import *
